# gdz
<img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></img>

Враппер API [приложения gdz.ru](https://play.google.com/store/apps/details?id=com.gdz_ru&hl=ru).